@@ -1,8 +1,8 @@
 use std::io::Write;
 use std::vec::Vec;
 
-use ansi_term::Colour::{Fixed, Green, Red, Yellow};
-use ansi_term::Style;
+use nu_ansi_term::Color::{Fixed, Green, Red, Yellow};
+use nu_ansi_term::Style;
 
 use bytesize::ByteSize;
 
@@ -93,7 +93,11 @@ impl<'a> Printer for SimplePrinter<'a> {
     ) -> Result<()> {
         if !out_of_range {
             if self.config.show_nonprintable {
-                let line = replace_nonprintable(line_buffer, self.config.tab_width);
+                let line = replace_nonprintable(
+                    line_buffer,
+                    self.config.tab_width,
+                    self.config.nonprintable_notation,
+                );
                 write!(handle, "{}", line)?;
             } else {
                 handle.write_all(line_buffer)?
@@ -422,7 +426,11 @@ impl<'a> Printer for InteractivePrinter<'a> {
         line_buffer: &[u8],
     ) -> Result<()> {
         let line = if self.config.show_nonprintable {
-            replace_nonprintable(line_buffer, self.config.tab_width)
+            replace_nonprintable(
+                line_buffer,
+                self.config.tab_width,
+                self.config.nonprintable_notation,
+            )
         } else {
             let line = match self.content_type {
                 Some(ContentType::BINARY) | None => {
@@ -621,7 +629,7 @@ impl<'a> Printer for InteractivePrinter<'a> {
                                         "{}\n{}",
                                         as_terminal_escaped(
                                             style,
-                                            &*format!("{}{}", self.ansi_style, line_buf),
+                                            &format!("{}{}", self.ansi_style, line_buf),
                                             self.config.true_color,
                                             self.config.colored_output,
                                             self.config.use_italic_text,
@@ -647,7 +655,7 @@ impl<'a> Printer for InteractivePrinter<'a> {
                                 "{}",
                                 as_terminal_escaped(
                                     style,
-                                    &*format!("{}{}", self.ansi_style, line_buf),
+                                    &format!("{}{}", self.ansi_style, line_buf),
                                     self.config.true_color,
                                     self.config.colored_output,
                                     self.config.use_italic_text,
