@@ -18,7 +18,7 @@ gpl_occurances=$(git grep --recurse-submodules "${gpl_term}" -- "${gpl_excludes[
 if [ -z "${gpl_occurances}" ]; then
     echo "PASS: No files under GPL were found"
 else
-    echo "FAIL: GPL:ed code is not compatible with bat, but occurances of '${gpl_term}' were found:"
+    echo "FAIL: GPL:ed code is not compatible with bat, but occurrences of '${gpl_term}' were found:"
     echo "${gpl_occurances}"
     exit 1
 fi
